@@ -296,7 +296,7 @@ class Vasprun(object):
         """
         True if run is spin-polarized.
         """
-        return True if self.incar.get("ISPIN", 1) == 2 else False
+        return True if self.parameters.get("ISPIN", 1) == 2 else False
 
     def get_band_structure(self, kpoints_filename=None, efermi=None,
                            line_mode=False):
@@ -428,6 +428,7 @@ class Vasprun(object):
                     eigenvals = {Spin.up: up_eigen}
             else:
                 labels_dict = dict(zip(kpoint_file.labels, kpoint_file.kpts))
+                labels_dict.pop(None, None)
             return BandStructureSymmLine(kpoints, eigenvals, lattice_new,
                                          efermi, labels_dict,
                                          structure=self.final_structure,
@@ -520,6 +521,7 @@ class Vasprun(object):
         vout['dielectric'] = self.dielectric
 
         peigen = []
+
         if len(self.projected_eigenvalues) != 0:
             for i in range(len(eigen)):
                 peigen.append({})
