@@ -106,17 +106,18 @@ class PDPlotter(object):
 
         return lines, stable_entries, unstable_entries
 
-    def show(self, label_stable=True, label_unstable=True):
+    def show(self, label_stable=True, label_unstable=True, ordering=None, energy_colormap=None):
         """
         Draws the phase diagram using Matplotlib and show it.
         """
         if self._dim < 4:
-            plt = self._get_2d_plot(label_stable, label_unstable)
+            plt = self._get_2d_plot(label_stable, label_unstable, ordering, energy_colormap)
         elif self._dim == 4:
             plt = self._get_3d_plot(label_stable)
         plt.show()
 
-    def _get_2d_plot(self, label_stable=True, label_unstable=True):
+    def _get_2d_plot(self, label_stable=True, label_unstable=True, ordering=None, energy_colormap=None,
+                     vmin_mev=-200.0, vmax_mev=200.0, show_colorbar=True):
         """
         Shows the plot using pylab.  Usually I won"t do imports in methods,
         but since plotting is a fairly expensive library to load and not all
@@ -125,10 +126,41 @@ class PDPlotter(object):
 
         plt = get_publication_quality_plot(8, 6)
         from matplotlib.font_manager import FontProperties
-        (lines, labels, unstable) = self.pd_plot_data
-        for x, y in lines:
-            plt.plot(x, y, "ko-", linewidth=3, markeredgecolor="k",
-                     markerfacecolor="b", markersize=15)
+        if ordering is None:
+            (lines, labels, unstable) = self.pd_plot_data
+        else:
+            (_lines, _labels, _unstable) = self.pd_plot_data
+            (lines, labels, unstable) = order_phase_diagram(_lines, _labels, _unstable, ordering)
+        if energy_colormap is None:
+            for x, y in lines:
+                plt.plot(x, y, "ko-", linewidth=3, markeredgecolor="k",
+                         markerfacecolor="b", markersize=15)
+        else:
+            from matplotlib.colors import Normalize, LinearSegmentedColormap
+            from matplotlib.cm import ScalarMappable
+            from pymatgen.phasediagram.pdanalyzer import PDAnalyzer
+            pda = PDAnalyzer(self._pd)
+            for x, y in lines:
+                plt.plot(x, y, "k-", linewidth=3, markeredgecolor="k")
+            vmin = vmin_mev / 1000.0
+            vmax = vmax_mev / 1000.0
+            if energy_colormap == 'default':
+                mid = -vmin/(vmax-vmin)
+                cmap = LinearSegmentedColormap.from_list('my_colormap', [(0.0 ,'#005500'),
+                                                                         (mid, '#55FF55'),
+                                                                         (mid, '#FFAAAA'),
+                                                                         (1.0, '#FF0000')])
+            else:
+                cmap = energy_colormap
+            norm = Normalize(vmin=vmin, vmax=vmax)
+            map = ScalarMappable(norm=norm, cmap=cmap)
+            _energies = [pda.get_equilibrium_reaction_energy(entry) for coord, entry in labels.iteritems()]
+            energies = [en if en < 0.0 else -0.00000001 for en in _energies]
+            vals_stable = map.to_rgba(energies)
+            ii = 0
+            for x, y in labels.iterkeys():
+                plt.plot(x, y, "o", markerfacecolor=vals_stable[ii], markersize=15)
+                ii+=1
         font = FontProperties()
         font.set_weight("bold")
         font.set_size(24)
@@ -180,19 +212,37 @@ class PDPlotter(object):
         if self.show_unstable:
             font = FontProperties()
             font.set_size(16)
+            energies_unstable = [pda.get_e_above_hull(entry) for entry, coord in unstable.iteritems()]
+            energies.extend(energies_unstable)
+            vals_unstable = map.to_rgba(energies_unstable)
+            ii = 0
             for entry, coords in unstable.items():
                 vec = (np.array(coords) - center)
-                vec = vec / np.linalg.norm(vec) * 10
+                vec = vec / np.linalg.norm(vec) * 10 \
+                    if np.linalg.norm(vec) != 0 else vec
                 label = entry.name
-                plt.plot(coords[0], coords[1], "ks", linewidth=3,
-                         markeredgecolor="k", markerfacecolor="r",
-                         markersize=8)
+                if energy_colormap is None:
+                    plt.plot(coords[0], coords[1], "ks", linewidth=3,
+                             markeredgecolor="k", markerfacecolor="r",
+                             markersize=8)
+                else:
+                    plt.plot(coords[0], coords[1], "s", linewidth=3,
+                             markeredgecolor="k", markerfacecolor=vals_unstable[ii],
+                             markersize=8)
                 if label_unstable:
                     plt.annotate(latexify(label), coords, xytext=vec,
                                  textcoords="offset points",
                                  horizontalalignment=halign, color="b",
                                  verticalalignment=valign,
                                  fontproperties=font)
+                ii += 1
+        if energy_colormap is not None and show_colorbar:
+            map.set_array(energies)
+            cbar = plt.colorbar(map)
+            cbar.set_label('Energy [meV] above hull (in red)\nInverse energy [meV] above hull (in green)',
+                           rotation=-90, ha='left', va='center')
+            ticks = cbar.ax.get_yticklabels()
+            cbar.ax.set_yticklabels(['${v}$'.format(v=float(t.get_text().strip('$'))*1000.0) for t in ticks])
         F = plt.gcf()
         F.set_size_inches((8, 6))
         plt.subplots_adjust(left=0.09, right=0.98, top=0.98, bottom=0.07)
@@ -232,7 +282,7 @@ class PDPlotter(object):
         ax.axis("off")
         return plt
 
-    def write_image(self, stream, image_format="svg"):
+    def write_image(self, stream, image_format="svg", ordering=None, energy_colormap=None):
         """
         Writes the phase diagram to an image in a stream.
 
@@ -244,7 +294,7 @@ class PDPlotter(object):
                 Defaults to svg for best results for vector graphics.
         """
         if self._dim < 4:
-            plt = self._get_2d_plot()
+            plt = self._get_2d_plot(ordering=ordering, energy_colormap=energy_colormap)
         elif self._dim == 4:
             plt = self._get_3d_plot()
 
@@ -461,3 +511,138 @@ def tet_coord(coord):
                         [0.5, 1.0 / 3.0 * math.sqrt(3) / 2, math.sqrt(6) / 3]])
     result = np.dot(np.array(coord), unitvec)
     return result.transpose()
+
+
+def order_phase_diagram(lines, stable_entries, unstable_entries, ordering):
+    """
+    Orders the entries (their coordinates) in a phase diagram plot according to the user specified ordering.
+    Ordering should be given as ['Up','Left','Right'], where Up, Left and Right are the names of the entries
+    in the upper, left and right corners of the triangle respectively.
+
+    Args:
+        lines:
+            list of list of coordinates for lines in the PD.
+        stable_entries:
+            {coordinate : entry} for each stable node in the phase diagram.
+            (Each coordinate can only have one stable phase)
+        unstable_entries:
+            {entry: coordinates} for all unstable nodes in the phase diagram.
+        ordering:
+            Ordering of the phase diagram, given as a list ['Up','Left','Right']
+
+    Returns:
+        (newlines, newstable_entries, newunstable_entries):
+                - newlines is a list of list of coordinates for lines in the PD.
+                - newstable_entries is a {coordinate : entry} for each stable node
+                  in the phase diagram. (Each coordinate can only have one
+                  stable phase)
+                - newunstable_entries is a {entry: coordinates} for all unstable
+                  nodes in the phase diagram.
+    """
+    yup = -1000.0
+    xleft = 1000.0
+    xright = -1000.0
+
+    for coord in stable_entries:
+        if coord[0] > xright:
+            xright = coord[0]
+            nameright = stable_entries[coord].name
+        if coord[0] < xleft:
+            xleft = coord[0]
+            nameleft = stable_entries[coord].name
+        if coord[1] > yup:
+            yup = coord[1]
+            nameup = stable_entries[coord].name
+
+    if (not nameup in ordering) or (not nameright in ordering) or (not nameleft in ordering):
+        raise ValueError('Error in ordering_phase_diagram : \n"{up}", "{left}" and "{right}" '
+                         'should be in ordering : {ord}'.format(up=nameup,
+                                                                left=nameleft,
+                                                                right=nameright,
+                                                                ord=ordering))
+
+    cc = np.array([0.5, np.sqrt(3.0) / 6.0], np.float)
+
+    if nameup == ordering[0]:
+        if nameleft == ordering[1]:
+            # The coordinates were already in the user ordering
+            return lines, stable_entries, unstable_entries
+        else:
+            newlines = [[np.array(1.0 - x), y] for x, y in lines]
+            newstable_entries = {(1.0 - c[0], c[1]): entry for c, entry in stable_entries.iteritems()}
+            newunstable_entries = {entry: (1.0 - c[0], c[1]) for entry, c in unstable_entries.iteritems()}
+            return newlines, newstable_entries, newunstable_entries
+    elif nameup == ordering[1]:
+        if nameleft == ordering[2]:
+            c120 = np.cos(2.0 * np.pi / 3.0)
+            s120 = np.sin(2.0 * np.pi / 3.0)
+            newlines = []
+            for x, y in lines:
+                newx = np.zeros_like(x)
+                newy = np.zeros_like(y)
+                for ii, xx in enumerate(x):
+                    newx[ii] = c120*(xx-cc[0])-s120*(y[ii]-cc[1])+cc[0]
+                    newy[ii] = s120*(xx-cc[0])+c120*(y[ii]-cc[1])+cc[1]
+                newlines.append([newx,newy])
+            newstable_entries = {(c120*(c[0]-cc[0])-s120*(c[1]-cc[1])+cc[0],
+                                  s120*(c[0]-cc[0])+c120*(c[1]-cc[1])+cc[1]): entry
+                                 for c, entry in stable_entries.iteritems()}
+            newunstable_entries = {entry: (c120*(c[0]-cc[0])-s120*(c[1]-cc[1])+cc[0],
+                                           s120*(c[0]-cc[0])+c120*(c[1] - cc[1])+cc[1])
+                                   for entry, c in unstable_entries.iteritems()}
+            return newlines, newstable_entries, newunstable_entries
+        else:
+            c120 = np.cos(2.0 * np.pi / 3.0)
+            s120 = np.sin(2.0 * np.pi / 3.0)
+            newlines = []
+            for x, y in lines:
+                newx = np.zeros_like(x)
+                newy = np.zeros_like(y)
+                for ii, xx in enumerate(x):
+                    newx[ii] = -c120*(xx-1.0)-s120*y[ii]+1.0
+                    newy[ii] = -s120*(xx-1.0)+c120*y[ii]
+                newlines.append([newx,newy])
+            newstable_entries = {(-c120*(c[0]-1.0)-s120*c[1]+1.0,
+                                  -s120*(c[0]-1.0)+c120*c[1]): entry
+                                 for c, entry in stable_entries.iteritems()}
+            newunstable_entries = {entry: (-c120*(c[0]-1.0)-s120*c[1]+1.0,
+                                           -s120*(c[0]-1.0)+c120*c[1])
+                                   for entry, c in unstable_entries.iteritems()}
+            return newlines, newstable_entries, newunstable_entries
+    elif nameup == ordering[2]:
+        if nameleft == ordering[0]:
+            c240 = np.cos(4.0 * np.pi / 3.0)
+            s240 = np.sin(4.0 * np.pi / 3.0)
+            newlines = []
+            for x, y in lines:
+                newx = np.zeros_like(x)
+                newy = np.zeros_like(y)
+                for ii, xx in enumerate(x):
+                    newx[ii] = c240*(xx-cc[0])-s240*(y[ii]-cc[1])+cc[0]
+                    newy[ii] = s240*(xx-cc[0])+c240*(y[ii]-cc[1])+cc[1]
+                newlines.append([newx,newy])
+            newstable_entries = {(c240*(c[0]-cc[0])-s240*(c[1]-cc[1])+cc[0],
+                                  s240*(c[0]-cc[0])+c240*(c[1]-cc[1])+cc[1]): entry
+                                 for c, entry in stable_entries.iteritems()}
+            newunstable_entries = {entry: (c240*(c[0]-cc[0])-s240*(c[1]-cc[1])+cc[0],
+                                           s240*(c[0]-cc[0])+c240*(c[1] - cc[1])+cc[1])
+                                   for entry, c in unstable_entries.iteritems()}
+            return newlines, newstable_entries, newunstable_entries
+        else:
+            c240 = np.cos(4.0 * np.pi / 3.0)
+            s240 = np.sin(4.0 * np.pi / 3.0)
+            newlines = []
+            for x, y in lines:
+                newx = np.zeros_like(x)
+                newy = np.zeros_like(y)
+                for ii, xx in enumerate(x):
+                    newx[ii] = -c240*xx-s240*y[ii]
+                    newy[ii] = -s240*xx+c240*y[ii]
+                newlines.append([newx,newy])
+            newstable_entries = {(-c240*c[0]-s240*c[1],
+                                  -s240*c[0]+c240*c[1]): entry
+                                 for c, entry in stable_entries.iteritems()}
+            newunstable_entries = {entry: (-c240*c[0]-s240*c[1],
+                                           -s240*c[0]+c240*c[1])
+                                   for entry, c in unstable_entries.iteritems()}
+            return newlines, newstable_entries, newunstable_entries
