@@ -126,6 +126,13 @@ def deprecated(replacement=None):
     """
     Decorator to mark classes or functions as deprecated,
     with a possible replacement.
+
+    Args:
+        replacement:
+            A replacement class or method.
+
+    Returns:
+        Original function, but with a warning to use the updated class.
     """
     def wrap(old):
         def wrapped(*args, **kwargs):
@@ -137,4 +144,41 @@ def deprecated(replacement=None):
             warnings.warn(msg, DeprecationWarning, stacklevel=2)
             return old(*args, **kwargs)
         return wrapped
-    return wrap
\ No newline at end of file
+    return wrap
+
+
+class requires(object):
+    """
+    Decorator to mark classes or functions as requiring a specified condition
+    to be true. This can be used to present useful error messages for
+    optional dependencies. For example, decorating the following code will
+    check if scipy is present and if not, a runtime error will be raised if
+    someone attempts to call the use_scipy function::
+
+        try:
+            import scipy
+        except ImportError:
+            scipy = None
+
+        @requires(scipy is not None, "scipy is not present.")
+        def use_scipy():
+            print scipy.majver
+
+    Args:
+        condition:
+            Condition necessary to use the class or function.
+        message:
+            A message to be displayed if the condition is not True.
+    """
+
+    def __init__(self, condition, message):
+        self.condition = condition
+        self.message = message
+
+    def __call__(self, callable):
+        @wraps(callable)
+        def decorated(*args, **kwargs):
+            if not self.condition:
+                raise RuntimeError(self.message)
+            return callable(*args, **kwargs)
+        return decorated
